Type: Package
Package: tidyfinance
Title: Tidy Finance Helper Functions
Version: 0.5.0
Authors@R: c(
    person("Christoph", "Scheuch", , "christoph@tidy-intelligence.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0009-0004-0423-6819")),
    person("Stefan", "Voigt", , "stefan.voigt@econ.ku.dk", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0001-5619-3161")),
    person("Patrick", "Weiss", , "patrickw@ru.is", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0002-9282-5872")),
    person("Maximilian", "Mücke", role = "ctb",
           comment = c(ORCID = "0009-0000-9432-9795"))
  )
Description: Helper functions for empirical research in financial
    economics, addressing a variety of topics covered in Scheuch, Voigt,
    and Weiss (2023) <doi:10.1201/b23237>.  The package is designed to
    provide shortcuts for issues extensively discussed in the book,
    facilitating easier application of its concepts. For more information
    and resources related to the book, visit
    <https://www.tidy-finance.org/r/index.html>.
License: MIT + file LICENSE
URL: https://www.tidy-finance.org/r/,
        https://github.com/tidy-finance/r-tidyfinance
BugReports: https://github.com/tidy-finance/r-tidyfinance/issues
Depends: R (>= 4.1)
Imports: arrow, cli, dplyr (>= 1.1.4), dbplyr (>= 2.5.0), glue,
        jsonlite, lifecycle, lubridate (>= 1.9.3), purrr (>= 1.0.2),
        rlang (>= 1.1.3), slider (>= 0.3.1), stats, stringr, tibble,
        tidyr (>= 1.3.1), DBI (>= 1.2.2), frenchdata (>= 0.2.0), httr2
        (>= 1.0.0), RPostgres (>= 1.4.5), sandwich (>= 3.1-0)
Suggests: knitr, rmarkdown, furrr (>= 0.3.1), testthat (>= 3.2.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-12 14:31:15 UTC; krise
Author: Christoph Scheuch [aut, cre, cph] (ORCID:
    <https://orcid.org/0009-0004-0423-6819>),
  Stefan Voigt [aut, cph] (ORCID:
    <https://orcid.org/0000-0001-5619-3161>),
  Patrick Weiss [aut, cph] (ORCID:
    <https://orcid.org/0000-0002-9282-5872>),
  Maximilian Mücke [ctb] (ORCID: <https://orcid.org/0009-0000-9432-9795>)
Maintainer: Christoph Scheuch <christoph@tidy-intelligence.com>
Repository: CRAN
Date/Publication: 2026-05-12 15:00:02 UTC
Built: R 4.6.0; ; 2026-05-12 19:55:02 UTC; unix
