# Generated by roxygen2: do not edit by hand

export(add_lagged_columns)
export(assign_portfolio)
export(breakpoint_options)
export(compute_breakpoints)
export(compute_long_short_returns)
export(compute_portfolio_returns)
export(compute_rolling_value)
export(create_summary_statistics)
export(create_wrds_dummy_database)
export(data_options)
export(disconnect_connection)
export(download_data)
export(download_data_constituents)
export(download_data_factors_ff)
export(download_data_factors_q)
export(download_data_fred)
export(download_data_huggingface)
export(download_data_macro_predictors)
export(download_data_osap)
export(download_data_risk_free)
export(download_data_stock_prices)
export(download_data_wrds)
export(download_data_wrds_ccm_links)
export(download_data_wrds_compustat)
export(download_data_wrds_crsp)
export(download_data_wrds_fisd)
export(download_data_wrds_trace_enhanced)
export(estimate_betas)
export(estimate_fama_macbeth)
export(estimate_model)
export(filter_options)
export(filter_sorting_data)
export(get_available_huggingface_files)
export(get_wrds_connection)
export(implement_portfolio_sort)
export(join_lagged_values)
export(list_supported_indexes)
export(list_supported_types)
export(list_tidy_finance_chapters)
export(open_tidy_finance_website)
export(portfolio_sort_options)
export(set_wrds_credentials)
export(trim)
export(validate_dates)
export(winsorize)
import(DBI)
import(dplyr)
import(httr2)
import(lubridate)
import(tibble)
importFrom(RPostgres,Postgres)
importFrom(arrow,read_parquet)
importFrom(arrow,write_parquet)
importFrom(dbplyr,translate_sql)
importFrom(frenchdata,download_french_data)
importFrom(frenchdata,get_french_data_list)
importFrom(jsonlite,fromJSON)
importFrom(lifecycle,deprecated)
importFrom(purrr,map)
importFrom(purrr,map_dbl)
importFrom(purrr,partial)
importFrom(rlang,":=")
importFrom(rlang,enquo)
importFrom(rlang,quo_is_null)
importFrom(rlang,syms)
importFrom(sandwich,NeweyWest)
importFrom(stats,as.formula)
importFrom(stats,ave)
importFrom(stats,na.omit)
importFrom(stats,quantile)
importFrom(stats,setNames)
importFrom(stats,weighted.mean)
importFrom(stringr,str_match)
importFrom(tidyr,drop_na)
importFrom(tidyr,fill)
importFrom(tidyr,nest)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,unnest)
importFrom(utils,read.csv)
